pub struct ExerciseTaskSubmissionCsvExportData {
pub exercise_slide_submission_id: Uuid,
pub exercise_task_submission_id: Uuid,
pub exercise_task_id: Uuid,
pub exercise_id: Uuid,
pub user_id: Uuid,
pub submitted_at: DateTime<Utc>,
pub answer: Option<Value>,
}Expand description
One row for CSV export: a single attempt at an exercise task for a given exercise_slide_submission (chronological submission order).
Fields
exercise_slide_submission_id: Uuidexercise_task_submission_id: Uuidexercise_task_id: Uuidexercise_id: Uuiduser_id: Uuidsubmitted_at: DateTime<Utc>answer: Option<Value>Trait Implementations
Sourceimpl Clone for ExerciseTaskSubmissionCsvExportData
impl Clone for ExerciseTaskSubmissionCsvExportData
Sourcefn clone(&self) -> ExerciseTaskSubmissionCsvExportData
fn clone(&self) -> ExerciseTaskSubmissionCsvExportData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExerciseTaskSubmissionCsvExportData
impl<'de> Deserialize<'de> for ExerciseTaskSubmissionCsvExportData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ExerciseTaskSubmissionCsvExportData
impl PartialEq for ExerciseTaskSubmissionCsvExportData
Sourcefn eq(&self, other: &ExerciseTaskSubmissionCsvExportData) -> bool
fn eq(&self, other: &ExerciseTaskSubmissionCsvExportData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExerciseTaskSubmissionCsvExportData